@@ -7,6 +7,8 @@ import logging
 from deskbar.ui.cuemiac.CuemiacItems import CuemiacCategory
 from deskbar.interfaces import Match
 
+LOGGER = logging.getLogger(__name__)
+
 class CellRendererCuemiacCategory (gtk.CellRendererText):
     """
     Special cell renderer for the CuemiacTreeView.
@@ -262,12 +264,12 @@ class CuemiacTreeView (gtk.TreeView):
         hit_title.connect("do-action-activated", self.__on_do_action_activated)
         hit_title.set_property ("ellipsize", pango.ELLIPSIZE_END)
        
-        hits = gtk.TreeViewColumn ("Hits")
-        hits.pack_start (icon, expand=False)
-        hits.pack_start (hit_title)
-        hits.set_cell_data_func(hit_title, self.__get_match_title_for_cell)            
-        hits.set_cell_data_func(icon, self.__get_match_icon_for_cell)
-        self.append_column (hits)
+        self._hits_column = gtk.TreeViewColumn ("Hits")
+        self._hits_column.pack_start (icon, expand=False)
+        self._hits_column.pack_start (hit_title)
+        self._hits_column.set_cell_data_func(hit_title, self.__get_match_title_for_cell)            
+        self._hits_column.set_cell_data_func(icon, self.__get_match_icon_for_cell)
+        self.append_column (self._hits_column)
         
         #self.set_reorderable(True)
         # FIXME: Make it so that categories *only* can be reordered by dragging
@@ -366,7 +368,7 @@ class CuemiacTreeView (gtk.TreeView):
                 cell.set_property ("pixbuf", match.get_icon())
                 cell.set_property ("visible", True)
             else:
-                logging.error("See bug 359251 and report this output: Match object of unexpected type: %r - %r" % (match.__class__, match))
+                LOGGER.error("See bug 359251 or 471672 and report this output: Match object of unexpected type: %r - %r" % (match.__class__, match))
                 cell.set_property ("pixbuf", None)
                 cell.set_property ("visible", False)
         
@@ -386,9 +388,13 @@ class CuemiacTreeView (gtk.TreeView):
         cell.set_property ("height", -1)
         cell.set_property ("cell-background-gdk", self.style.base[gtk.STATE_NORMAL])
         
-        cell.set_property ("has-more-actions", len(match.get_actions()) > 1)
-                
-        cell.set_property ("markup", model[iter][model.ACTIONS])
+        if match == None:
+            LOGGER.error("See bug 359251 or 471672 and report this output: Match object of unexpected type: %r - %r" % (match.__class__, match))
+            cell.set_property ("has-more-actions", False)
+            cell.set_property ("markup", "")
+        else:
+            cell.set_property ("has-more-actions", len(match.get_actions()) > 1)
+            cell.set_property ("markup", model[iter][model.ACTIONS])
         
     def __on_show_actions_activated(self, widget, path):
         col = self.get_model().ACTIONS
@@ -407,6 +413,8 @@ class CuemiacTreeView (gtk.TreeView):
         match = model[iter][model.MATCHES]
         qstring = model[iter][model.QUERY]
         
+        # Used by LingeringSelectionWindow
+        self.emit("row-activated", path, self._hits_column)
         self.emit("do-default-action", qstring, match, event)
 
     def __on_activated (self, treeview, path, col, event=None):
